#
# spec file for package docbook_5
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define schemaversions 5.0 5.1 5.2CR5
%define realversion 5.2CR5
#
Name:           docbook_5
Version:        5.2cr5
Release:        2.1
Summary:        DocBook Schemas (DTD, RELAX NG, W3C Schema) for Version 5.x
License:        SUSE-Oasis-Specification-Notice
Group:          Productivity/Publishing/DocBook
URL:            https://www.oasis-open.org/docbook/
# XML Catalog Entry
Source1:        %{name}.xml
Source2:        %{name}-README.SUSE
# DocBook Sources
Source3:        docbook-5.0-docs.tar.bz2
Source4:        docbook-5.1-docs.tar.bz2
Source6:        Makefile
# For testing
Source10:       check-catalog.sh

# DB 5.0
Source500:      docbook-5.0.tar.bz2
# DB 5.1
Source510:      docbook-5.1.tar.bz2
# DB 5.2
Source520:      docbook-%{realversion}.zip
# PATCH-FIX-OPENSUSE docbook_5-nvdl.patch change path to schema files
Patch501:       %{name}-nvdl.patch
#
BuildRequires:  fdupes
BuildRequires:  libxml2-tools
BuildRequires:  sgml-skel
BuildRequires:  unzip
BuildRequires:  xmlstarlet
Requires:       sgml-skel >= 0.7
Requires(post): sgml-skel >= 0.7
Requires(postun):sgml-skel >= 0.7
BuildArch:      noarch

%description
DocBook is a schema. It is particularly well-suited to books and papers
about computer hardware and software (though it is not limited to these
applications at all).

Version 5 is a complete rewrite of DocBook in RELAX NG.
The intent of this rewrite is to produce a schema that is true to the
spirit of DocBook while simultaneously removing inconsistencies that
have arisen as a natural consequence of DocBook's long, slow evolution.

%package doc
Summary:        Documentation for %{name}
Group:          Documentation/HTML
BuildArch:      noarch

%description doc
The documentation for the DocBook 5.x specification (%{schemaversions})

%define xml_dir                %{_datadir}/xml
%define xml_docbook_dir        %{xml_dir}/docbook
%define xml_schema_dir         %{xml_dir}/docbook/schema
%define xml_docbook_dtd_dir    %{xml_schema_dir}/dtd
%define xml_docbook_rng_dir    %{xml_schema_dir}/rng
%define xml_docbook_sch_dir    %{xml_schema_dir}/sch
%define xml_docbook_xsd_dir    %{xml_schema_dir}/xsd
%define xml_docbook_nvdl_dir   %{xml_schema_dir}/nvdl
%define xml_docbook_custom_dir %{xml_docbook_dir}/custom
%define xml_docbook_style_dir  %{xml_docbook_dir}/stylesheet
%define xml_config_dir         %{_localstatedir}/lib/xml
%define xml_sysconf_dir        %{_sysconfdir}/xml

%prep
%setup -q -n %{name} -c -T
sed -i 's_@VERSION@_%{realversion}_g' %{SOURCE1}
# Copy catalog, README, and Makefile
cp -p %{SOURCE1} %{SOURCE2} %{SOURCE6} .

# Unpack the sources:
tar -xf %{SOURCE500}
tar -xf %{SOURCE510}
unzip %{SOURCE520}
# Unpack the documentation:
tar -xf %{SOURCE3}
tar -xf %{SOURCE4}

chmod -R a+rX,g-w,o-w .
find . -type f | xargs chmod a-x

# Patching
%patch501

%build
# Nothing to build

%install
make DESTDIR=%{buildroot}

# cleanup
%fdupes %{buildroot}

%post
update-xml-catalog

%postun
update-xml-catalog

%check
%define catalog %{buildroot}%{xml_sysconf_dir}/catalog.d/docbook_5.xml
cp -p %{SOURCE10} .
chmod +x check-catalog.sh

./check-catalog.sh --buildroot %{buildroot} "%{catalog}"

%files
%config %{xml_sysconf_dir}/catalog.d/docbook_5.xml
%doc *README*
%doc docbook-%{realversion}/release-notes

#
%dir %{xml_docbook_dir}/schema
%dir %{xml_docbook_dtd_dir}
%dir %{xml_docbook_rng_dir}
%dir %{xml_docbook_sch_dir}
%dir %{xml_docbook_xsd_dir}
%dir %{xml_docbook_nvdl_dir}
%dir %{xml_docbook_style_dir}
# 5.0
%{xml_docbook_dtd_dir}/5.0
%{xml_docbook_rng_dir}/5.0
%{xml_docbook_sch_dir}/5.0
%{xml_docbook_xsd_dir}/5.0
%{xml_docbook_nvdl_dir}/5.0
# 5.1
%{xml_docbook_rng_dir}/5.1
%{xml_docbook_sch_dir}/5.1
%{xml_docbook_nvdl_dir}/5.1
#5.2*
%{xml_docbook_sch_dir}/%{realversion}
%{xml_docbook_rng_dir}/%{realversion}
%{xml_docbook_nvdl_dir}/%{realversion}
#5.2
%{xml_docbook_sch_dir}/5.2
%{xml_docbook_rng_dir}/5.2
%{xml_docbook_nvdl_dir}/5.2
# Upgrade stylesheet
%{xml_docbook_style_dir}/upgrade
#
%{_bindir}/db4-entities.pl

%files doc
%doc docbook*spec-cd-01.{pdf,html,xml}
%doc docbook*-os.{pdf,html,xml}

%changelog
* Fri Mar  3 2023 Thomas Schraitle <thomas.schraitle@suse.com> - 5.2CR5
  Only spec file changes
- Introduce check-catalog.sh script in %%check section
  This script tests the docbook_5.xml XML catalog, extracts entries, and checks
  if the file exists.
- Add missing "/" in catalog file "docbook_5.xml"
  In several rewritePrefix attributes the missing "/" leads to invalid local paths.
  For example:
  $ xmlcatalog /etc/xml/catalog https://cdn.docbook.org/schema/5.2/rng/assemblyxi.rnc
  file:///usr/share/xml/docbook/schema/rng/5.2assemblyxi.rnc
  The ".../5.2assemblyxi.rnc" part should be ".../5.2/assemblyxi.rnc".
* Thu Feb  9 2023 Thomas Schraitle <thomas.schraitle@suse.com> - 5.2CR5
- Update to version 5.2CR5
  fixes a bug where the cols attribute on entrytbl element was
  incorrectly optional.
* Thu Feb  9 2023 Thomas Schraitle <thomas.schraitle@suse.com> - 5.2CR4
- Update to version 5.2CR4
  - Fix OASIS identifiers in catalog, CR4 (#245)
  - Allow info to be a top-level element in a document (#244)
  - Fix XInclude declarations, inconsistencies (#243)
  - Documentation updates (#242)
* Thu Dec  8 2022 Thomas Schraitle <thomas.schraitle@suse.com> - 5.2CR3
- Update to version 5.2CR3
  - PR #237 Allow namespace qualified attributes in non-DB namespaces
  - Add <modifier> after the main names in many OO classes
  - Some improvements for tests
- Update to version 5.2CR2
  - Added many new elements, for example meta, danger, enumsynopsis
  - Added otherclass attribute to article
  - Added otherclass attribute to section elements to support other values.
  - Added optional type attribute (text) to procedure element.
  - Added a type attribute to table and informaltable elements (CALS and HTML
    table syntax)
  - Added trans:idfixup, trans:suffix, and trans:linkscope to common attributes.
  - Changed abstract content from db.para.blocks+ to db.all.blocks+ to expand
    its content model
  Find the complete list in the release-notes folder
- Package changes
  - Add the release-notes folder in the spec file
  - Add %%check section in spec file for a minimal test
  - Correct version information in Makefile to create the correct link
  - Add @VERSION@ placeholder in XML catalog file docbook_5.xml which is
    replaced during build time
  - Add https://cdn.docbook.org/schema/<VERSION> in the XML catalog file
    docbook_5.xml
  - Update docbook_5-README.SUSE
* Mon May 30 2022 Thomas Schraitle <thomas.schraitle@suse.com> - 5.2CR1
- Update to version 5.2CR1
  - #230: Add packageref attribute for all *synopsis elements
  no changes from the 5.2b13 reviewed by the TC
* Wed Mar 16 2022 Thomas Schraitle <thomas.schraitle@suse.com> - 5.2b12
- Update to version 5.2b12:
  - Fix #223 by refactoring namespacesynopsis as packagesynopis
  - Fix #221 by setting the queryBinding on Schematron schemas to xslt2
- Update to version 5.2b11:
  - Fix #212 Incorrect XML catalog generation for CDN URIs.
  - Fix #216 A bug in the citetitle element; the otherpubwork attribute was missing
* Thu Jul 15 2021 Thomas Schraitle <thomas.schraitle@suse.com> - 5.2b10a5
- Update to version 5.2b10a5:
  - Fixed the bug where db.extension.inlines and db.extension.blocks were
    accidentally omitted from a4.
  - Made the name attribute on meta optional.
  - Fixed duplicate patterns in db.synopsis.blocks.
  - Improved the consistency of synopsisinfo by making it available in
    fieldsynopsis, constructorsynopsis, and destructorsynopsis.
- Spec file
  - Correct XML catalog entry and replaced wrong and old 5.210a2
    version with current version
  - Remove %%lastschemaversion variable, consolidate to %%version
* Fri Jul  9 2021 Thomas Schraitle <thomas.schraitle@suse.com> - 5.2b10a4
- Update to version 5.2b10a4:
  - Adding transclusion attributes as common attributes (#187)
  - Implementing legalsection as a class attribute (#186)
  - Add a type attribute to formal and informal objects (#185)
  - Add pubwork/otherpubwork to biblioentry/bibliomixed (#184)
  - Add a DocBook ITS + XInclude schema (#183)
  - Proposed fix for issues related to the new synopsis elements (#173)
  - Convert @name on s:pattern to s:title in ISO Schematron (#2)
- Update to version 5.2b10a3:
  - Add a general meta element (#176)
  - Fix XInclude issues on empty href, fragid (#175)
  - Add Schematron rules for productionset and callout (#174, #151, #162)
* Mon Aug 31 2020 Thomas Schraitle <thomas.schraitle@suse.com> - 5.2b10a2
- Spec improvements:
  move creating of compatibility links (5.2b10a2 -> 5.2) from spec
  file into Makefile
* Thu Aug  6 2020 mmuschner <mmuschner@localhost>  - 5.2b10a2
  Update to version 5.2b10a2:
  - Added a transform attribute to the resource element (as an alternative to grammar).
  - Removed the grammar attribute from output.
  - Added a danger admonition.
  - Added a legalsection sectioning element. Allow legalsection in legalnotice.
  - Added an otherclass attribute to article as an alternative to the enumerated class values.
  - Added a formalgroup element to contain several formal objects (for example, subfigures in a figure).
  - Relaxed the content model of abstract to include non-paragraph block elements.
  - Added multimediaparams to imagedata.
  - Added a buildtarget inline.
  - Allow funcdef to contain an explicit void.
  - Allow paramdef to contain modifiers.
  - Allow fieldsynopsis, methodsynopsis, and methodparam to contain more than one type.
  - Extended the content model of type so that it can represent union and intersection types. Added a class attribute to type.
  - Allow numbered sections (sect1, sect2, etc.) to contain refentry.
  - Added interface to the enumerated values in the class attribute of systemitem.-
  - Fix XML catalog to allow both www.docbook.org and docbook.org as URIs.
* Fri Dec  8 2017 dimstar@opensuse.org
- Fix fdupes macro invocation: the fdupes macro knows no -q
  parameter.
* Sun Nov 12 2017 thomas.schraitle@suse.com
- Correct Makefile:
  - Add more pattern rules
  - Use more builtin make functions
  - Create links in nvdl directory to docbook.{rng,sch}
  - Add missing assembly.rn{c,g} and dbits.rn{c,g} for Schematron
- Correct spec file:
  - Add docbook_5-nvdl.patch to change path to DocBook RNG/SCH files
  - Apply spec-cleaner
* Wed Oct 11 2017 thomas.schraitle@suse.com
- New version 5.1
  - no DTD and XSD schemas for version 5.1 anymore!
- Changes in spec file:
  - used spec-cleaner
  - removed obsolete stuff
  - install files through Makefile
  - install NVDL files under /usr/share/xml/docbook/schema/nvdl
    instead as "documentation"
* Fri Jun 17 2016 fvogt@suse.com
- Split documentation into -doc subpackage
- Use newer sgml-spec
* Tue May 12 2015 toms@opensuse.org
- Changed DocBook catalog URIs to 5.1 instead of 5.1CR3
* Thu Feb 19 2015 toms@opensuse.org
- Fixed subtle XML catalog bug (bsc#918565)
- Added DocBook 5.1CR3
- Spec file changes:
  . Make post and postun sections work
  . Lots of entries in XML catalogs need to be generated, so it's
    easier to use for loops
* Mon Mar 18 2013 cfarrell@suse.com
- license update: SUSE-Oasis-Specification-Notice
  See any of the files in the docs/ subdirectory (section on notices and ip
  towards the end)
* Fri Mar  1 2013 coolo@suse.com
- update license to new format
* Tue Jun  5 2012 ke@suse.de
- Reduce Requires (iso_ent and xmlcharent).
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
  (cf. packaging guidelines)
* Mon Aug  3 2009 aj@suse.de
- Only remove file from catalog if it disappeared.
- Do not use release numbers, they're not needed anymore.
- Cleanup some rpmlint warnings: Non-executable-in-bin, duplicate
  requires, do not remove buildroot.
* Mon Feb 11 2008 toms@suse.de
- Release of version 5.0 (Committee Draft)
  There are no user-visible changes in 5.0 (Public Review Draft 1).
  This version of DocBook V5.0 will become the official Committee
  Specification version of DocBook V5.0 as soon as the
  Technical Committee balloting process is finished.
- Added DocBook Specification in PDF, HTML and XML
* Thu May 24 2007 toms@suse.de
- Updated to release 5.0CR4:
  * Fixed RFE 1708032: Pattern naming inconsistency; changed
    db.href.attribute to db.href.attributes.
  * Fixed RFE 1700154: Added sortas to <termdef>.
  * Fixed RFE 1686919: Added an NVDL rules file.
  * Fixed RFE 1705596: Aded db.programming.inlines (<classname>,
    <exceptionname>, <function>, <initializer>, <interfacename>,
    <methodname>, <modifier>, <ooclass>, <ooexception>, <oointerface>,
    <parameter>, <returnvalue>, <type>, and <varname>) to the
    content model of <code>.
  * Fixed RFE 1689228: Fixed typo in Schematron assertion.
* Fri Mar 23 2007 toms@suse.de
- Updated to release 5.0CR3:
  * RFE 1679775: Changed semantics of <termdef>. A <firstterm> is now
    required (instead of a <glossterm> as in previous releases). This
    allows the definition of one term to refer to another.
  * RFE 1682917: Added pgwide attribute to <example>.
  * RFE 1644553: Added label attribute to CALS and HTML tables.
  * RFE 1588693: Added an <acknowledgements> element, peer to
    <dedication>, replacing <ackno> which had only been available at the
    end of <article>.
  * After several months of consideration and experimentation, we decided
    to allow <info> in HTML tables.
  * RFE 1673820: Adopted "http://docbook.org/xlink/role/olink" as an XLink
    role (that is, the xlink:role attribute) value to identify OLinks
    expressed using XLink attributes.
* Wed Mar 14 2007 toms@suse.de
- Updated to release 5.0CR2:
  * Fixed RFE 1630203: Allow empty glossary.
  * Fixed RFE 1627845: Allow optional caption on CALS table and informaltable.
  * Related to RFE 1627845: Allow inlines in HTML table caption.
  * Fixed RFE 1589139 (and RFE 1621178): Allow title and titleabbrev on qandaentry.
  * Fixed RFE 1675932: Restore localname, prefix and namespace as class attribute values on tag.
  * Fixed RFE 1669465: Schematron rules should refer to @xml:id, not @id.
* Mon Feb 19 2007 toms@suse.de
- First release of 5.0CR1
